""" 

Context : SRP
Module  : Statistics
Version : 1.2.0
Author  : Stefano Covino
Date    : 19/02/2012
E-mail  : stefano.covino@brera.inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino


Usage   : to be imported

Remarks :

History : (28/10/2010) First version.
        : (30/04/2011) ChiSqIncrement.
        : (19/02/2012) ScoreatPercentile.
"""



__all__ = ['AsymmetricGaussianDistrib', 'AverIterSigmaClipp', 'AverSigmaClippFrame', 'ChSqIncrement',
            'CoordDistanceMinimization', 'GenGaussSet', 'ScoreatPercentile', 'WeightedMean', 'WeightedMeanFrame']

